==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/all_75.js <==
var searchData=
[
  ['uchar_5ftype',['UCHAR_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0a431d01a737e659afd352bff1785d9efb',1,'viennacl::scheduler']]],
  ['uint16_5ft',['uint16_t',['../namespaceviennacl_1_1tools.html#a41c7aba990e19f619861ccb6ecfa6202',1,'viennacl::tools']]],
  ['uint32_5ft',['uint32_t',['../namespaceviennacl_1_1tools.html#a8e167761425794c5de47fc9cfc3ebd7e',1,'viennacl::tools']]],
  ['uint8_5ft',['uint8_t',['../namespaceviennacl_1_1tools.html#a6e937a2558f89f292719ff40be44c3fa',1,'viennacl::tools']]],
  ['uint_5ftype',['UINT_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0af3a814805fa7be3207eabd6cbb658534',1,'viennacl::scheduler']]],
  ['ulong_5ftype',['ULONG_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0a49c6e1fa184497688a25b2d8a14e04f7',1,'viennacl::scheduler']]],
  ['unary_5felement_5fop',['unary_element_op',['../namespaceviennacl_1_1scheduler_1_1preset.html#aa11466374772f68e24f7ec8053dc859f',1,'viennacl::scheduler::preset']]],
  ['uniform_5frandom_5fnumbers',['uniform_random_numbers',['../classviennacl_1_1tools_1_1uniform__random__numbers.html',1,'viennacl::tools']]],
  ['unit_5flower_5ftag',['unit_lower_tag',['../structviennacl_1_1linalg_1_1unit__lower__tag.html',1,'viennacl::linalg']]],
  ['unit_5fupper_5ftag',['unit_upper_tag',['../structviennacl_1_1linalg_1_1unit__upper__tag.html',1,'viennacl::linalg']]],
  ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html',1,'viennacl']]],
  ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html#acf1edf2697940a7321bdfc8b4e4d459a',1,'viennacl::unit_vector']]],
  ['unknown',['unknown',['../namespaceviennacl_1_1ocl.html#ac19deb058c8b979eba1faba219542c35a316c69380aa261e30f2eca7f8f8881db',1,'viennacl::ocl']]],
  ['unknown_5ferror',['unknown_error',['../classviennacl_1_1ocl_1_1unknown__error.html',1,'viennacl::ocl']]],
  ['unknown_5fid',['unknown_id',['../namespaceviennacl_1_1ocl.html#aa17c812dad306869678f302d9338d177a9bb270cddf24cf1a843acc0e8e9050e6',1,'viennacl::ocl']]],
  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html',1,'viennacl']]],
  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html#a54d00eebcc284ec99fe2ad144f594265',1,'viennacl::unknown_norm_exception']]],
  ['up_5fto_5finternal_5fsize',['up_to_internal_size',['../classviennacl_1_1device__specific_1_1matrix__axpy__template.html#a3b489a3a6960699bfb85ffae95273882',1,'viennacl::device_specific::matrix_axpy_template::up_to_internal_size()'],['../classviennacl_1_1device__specific_1_1vector__axpy__template.html#a950bc84f7f5240d3b5fe3d584c9a0bfa',1,'viennacl::device_specific::vector_axpy_template::up_to_internal_size()']]],
  ['update_5ffloat_5fqr_5fcolumn',['update_float_QR_column',['../namespaceviennacl_1_1linalg_1_1detail.html#a4d6d704d39ec27eb15a604580eb1df5b',1,'viennacl::linalg::detail']]],
  ['update_5ffloat_5fqr_5fcolumn_5fgpu',['update_float_QR_column_gpu',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ce6438b322e096df65112ac6536b0b1',1,'viennacl::linalg::detail']]],
  ['upper_5finplace_5fsolve_5fmatrix',['upper_inplace_solve_matrix',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a38989d09acd0c0763276fd94123e9d51',1,'viennacl::linalg::host_based::detail']]],
  ['upper_5finplace_5fsolve_5fvector',['upper_inplace_solve_vector',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a96090fa88ab45b1c22ffc5038ce17b2d',1,'viennacl::linalg::host_based::detail']]],
  ['upper_5ftag',['upper_tag',['../structviennacl_1_1linalg_1_1upper__tag.html',1,'viennacl::linalg']]],
  ['use_5flevel_5fscheduling',['use_level_scheduling',['../classviennacl_1_1linalg_1_1ilu0__tag.html#a80e9be92f4b0b34a8150b6362cb7e969',1,'viennacl::linalg::ilu0_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilu0__tag.html#a95868f0f04b78bf99db86ca3380d8f43',1,'viennacl::linalg::ilu0_tag::use_level_scheduling(bool b)'],['../classviennacl_1_1linalg_1_1ilut__tag.html#ab151e8e08b42253c3de75a8a70047596',1,'viennacl::linalg::ilut_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilut__tag.html#a2042190ce53f7a4bb28356ffd3103a89',1,'viennacl::linalg::ilut_tag::use_level_scheduling(bool b)']]],
  ['ushort_5ftype',['USHORT_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0aa829bce847f24626bc32a9420d715562',1,'viennacl::scheduler']]],
  ['util_2ehpp',['util.hpp',['../linalg_2detail_2bisect_2util_8hpp.html',1,'']]],
  ['util_2ehpp',['util.hpp',['../backend_2util_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../device__specific_2templates_2utils_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../device__specific_2utils_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../ocl_2utils_8hpp.html',1,'']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/all_75.js <==
var searchData=
[
  ['uchar_5ftype',['UCHAR_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0a431d01a737e659afd352bff1785d9efb',1,'viennacl::scheduler']]],
  ['uint16_5ft',['uint16_t',['../namespaceviennacl_1_1tools.html#a41c7aba990e19f619861ccb6ecfa6202',1,'viennacl::tools']]],
  ['uint32_5ft',['uint32_t',['../namespaceviennacl_1_1tools.html#a8e167761425794c5de47fc9cfc3ebd7e',1,'viennacl::tools']]],
  ['uint8_5ft',['uint8_t',['../namespaceviennacl_1_1tools.html#a6e937a2558f89f292719ff40be44c3fa',1,'viennacl::tools']]],
  ['uint_5ftype',['UINT_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0af3a814805fa7be3207eabd6cbb658534',1,'viennacl::scheduler']]],
  ['ulong_5ftype',['ULONG_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0a49c6e1fa184497688a25b2d8a14e04f7',1,'viennacl::scheduler']]],
  ['uniform_5frandom_5fnumbers',['uniform_random_numbers',['../classviennacl_1_1tools_1_1uniform__random__numbers.html',1,'viennacl::tools']]],
  ['unit_5flower_5ftag',['unit_lower_tag',['../structviennacl_1_1linalg_1_1unit__lower__tag.html',1,'viennacl::linalg']]],
  ['unit_5fupper_5ftag',['unit_upper_tag',['../structviennacl_1_1linalg_1_1unit__upper__tag.html',1,'viennacl::linalg']]],
  ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html',1,'viennacl']]],
  ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html#acf1edf2697940a7321bdfc8b4e4d459a',1,'viennacl::unit_vector']]],
  ['unknown',['unknown',['../namespaceviennacl_1_1ocl.html#ac19deb058c8b979eba1faba219542c35a316c69380aa261e30f2eca7f8f8881db',1,'viennacl::ocl']]],
  ['unknown_5ferror',['unknown_error',['../classviennacl_1_1ocl_1_1unknown__error.html',1,'viennacl::ocl']]],
  ['unknown_5fid',['unknown_id',['../namespaceviennacl_1_1ocl.html#aa17c812dad306869678f302d9338d177a9bb270cddf24cf1a843acc0e8e9050e6',1,'viennacl::ocl']]],
  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html',1,'viennacl']]],
  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html#a54d00eebcc284ec99fe2ad144f594265',1,'viennacl::unknown_norm_exception']]],
  ['update_5ffloat_5fqr_5fcolumn',['update_float_QR_column',['../namespaceviennacl_1_1linalg_1_1detail.html#a4d6d704d39ec27eb15a604580eb1df5b',1,'viennacl::linalg::detail']]],
  ['update_5ffloat_5fqr_5fcolumn_5fgpu',['update_float_QR_column_gpu',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ce6438b322e096df65112ac6536b0b1',1,'viennacl::linalg::detail']]],
  ['upper_5finplace_5fsolve_5fmatrix',['upper_inplace_solve_matrix',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a38989d09acd0c0763276fd94123e9d51',1,'viennacl::linalg::host_based::detail']]],
  ['upper_5finplace_5fsolve_5fvector',['upper_inplace_solve_vector',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a96090fa88ab45b1c22ffc5038ce17b2d',1,'viennacl::linalg::host_based::detail']]],
  ['upper_5ftag',['upper_tag',['../structviennacl_1_1linalg_1_1upper__tag.html',1,'viennacl::linalg']]],
  ['use_5flevel_5fscheduling',['use_level_scheduling',['../classviennacl_1_1linalg_1_1ilu0__tag.html#a80e9be92f4b0b34a8150b6362cb7e969',1,'viennacl::linalg::ilu0_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilu0__tag.html#a95868f0f04b78bf99db86ca3380d8f43',1,'viennacl::linalg::ilu0_tag::use_level_scheduling(bool b)'],['../classviennacl_1_1linalg_1_1ilut__tag.html#ab151e8e08b42253c3de75a8a70047596',1,'viennacl::linalg::ilut_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilut__tag.html#a2042190ce53f7a4bb28356ffd3103a89',1,'viennacl::linalg::ilut_tag::use_level_scheduling(bool b)']]],
  ['ushort_5ftype',['USHORT_TYPE',['../namespaceviennacl_1_1scheduler.html#a4e3a8f20bd7e1a12a898442356ff52e0aa829bce847f24626bc32a9420d715562',1,'viennacl::scheduler']]],
  ['util_2ehpp',['util.hpp',['../backend_2util_8hpp.html',1,'']]],
  ['util_2ehpp',['util.hpp',['../linalg_2detail_2bisect_2util_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../ocl_2utils_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../device__specific_2templates_2utils_8hpp.html',1,'']]],
  ['utils_2ehpp',['utils.hpp',['../device__specific_2utils_8hpp.html',1,'']]]
];
